# OpexCore

### What is OpexCore?

A unified Python SDK for managing multiple VPN panels API.


### Clients

- [x] GuardCore
- [x] Marzban
- [x] Marzneshin
- [x] OvPanel
- [x] Pasarguard
- [x] Remnawave
- [ ] Rebbeca

### Installation

```bash
pip install opexcore
```

Check out the [examples](./examples/) directory for usage examples of each panel.
